<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * ajax server
 *
 * @package     block_helpmenow
 * @copyright   2012 VLACS
 * @author      David Zaharee <dzaharee@vlacs.org>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

# capture output
ob_start();

require_once((dirname(dirname(dirname(__FILE__)))) . '/config.php');
require_once(dirname(__FILE__) . '/lib.php');

if (!isloggedin()) {
    header('HTTP/1.1 401 Unauthorized');
    die;
}

# requests are sent as JSON object from the client
$requests = json_decode(file_get_contents('php://input'));

# special case for logging errors
if (isset($requests->error)) {
    helpmenow_log_error($requests);
    header('HTTP/1.1 200 OK');
    die;
}

# iterate through the requests and create responses
$responses = array();
foreach ($requests->requests as $request) {
    ob_start();
    try {
        # all responses need id of the request and client instance
        $response = (object) array(
            'id' => $request->id,
        );
        if (isset($request->instanceId)) {
            $response->instanceId = $request->instanceId;
        }

        # verify session where applicable
        switch ($request->function) {
        case 'message':
        case 'refresh':
            if (!$session2user = helpmenow_get_s2u($request->session)) {
                throw new Exception('Could not get session2user record');
            }
            break;
        }

        # generate response
        switch ($request->function) {
        case 'message':
        case 'refresh':
        case 'block':
        case 'motd':
        case 'plugin':
            $function = 'helpmenow_serverfunc_' . $request->function;
            $function($request, $response);
            break;
        default:
            throw new Exception('Unknown function');
        }
    } catch (Exception $e) {
        $response->error = $e->getMessage();
        // echo json_encode($response);
        // die;
    }
    $debugging = ob_get_clean();
    if (debugging()) {
        $response->debugging = $debugging;
    }
    $responses[] = $response;
}

header('Content-Type: application/json; charset=utf-8');
header('Cache-Control: no-cache');
header('Expires: '. gmdate('D, d M Y H:i:s', 0) .' GMT');
header('Pragma: no-cache');
echo json_encode($responses);

?>
