<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Help me now adobe connect plugin
 *
 * @package     block_helpmenow
 * @copyright   2012 VLACS
 * @author      David Zaharee <dzaharee@vlacs.org>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once(dirname(dirname(dirname(__FILE__))) . '/lib.php');

/**
 * Test to see if the adobeconnect url for the user is working, if it is, then 
 * show the link, otherwise show nothing.
 *
 * Cache this in the $SESSION to avoid lots of repeat queries to adobeconnect 
 * across the Interblag. The user can log out and back in if an update is 
 * necessary.
 */
function helpmenow_adobeconnect_urlexists() {
    global $USER, $CFG, $SESSION;

    if (!isset($SESSION->helpmenow_adobeconnect_urlexists[$USER->id])) {
        $SESSION->helpmenow_adobeconnect_urlexists = array();
    }
    if (!isset($SESSION->helpmenow_adobeconnect_urlexists[$USER->id])) {
        if (empty($CFG->helpmenow_adobeconnect_url)) {
            $SESSION->helpmenow_adobeconnect_urlexists[$USER->id] = false;
        } else {
            $url = "$CFG->helpmenow_adobeconnect_url/$USER->username";
            $ci = curl_init($url);
            curl_setopt($ci, CURLOPT_HEADER, TRUE);
            curl_setopt($ci, CURLOPT_NOBODY, TRUE);
            curl_setopt($ci, CURLOPT_FOLLOWLOCATION, FALSE);
            curl_setopt($ci, CURLOPT_RETURNTRANSFER, TRUE);
            $status = array();
            preg_match('/HTTP\/.* ([0-9]+) .*/', curl_exec($ci) , $status);
            $SESSION->helpmenow_adobeconnect_urlexists[$USER->id] = ($status[1] == 302);
        }
    }

    return $SESSION->helpmenow_adobeconnect_urlexists[$USER->id];
}

/**
 *     _____ _
 *    / ____| |
 *   | |    | | __ _ ___ ___  ___  ___
 *   | |    | |/ _` / __/ __|/ _ \/ __|
 *   | |____| | (_| \__ \__ \  __/\__ \
 *    \_____|_|\__,_|___/___/\___||___/
 */

/**
 * adobeconnect helpmenow plugin class
 */
class helpmenow_plugin_adobeconnect extends helpmenow_plugin {
    /**
     * Plugin name
     * @var string $plugin
     */
    public $plugin = 'adobeconnect';

    public static function display($sessionid, $privileged = false) {
        global $CFG, $USER;

        if (!helpmenow_adobeconnect_urlexists()) {
            return '';
        }

        if ($privileged) {
            $connect = new moodle_url("$CFG->wwwroot/blocks/helpmenow/plugins/adobeconnect/connect.php");
            $connect->param('sessionid', $sessionid);
            return link_to_popup_window($connect->out(), "adobe_connect", 'Invite to Adobe Connect', 400, 500, null, null, true);
        }
        return '';
    }

    /**
     * returns formatted information to put in the main block
     * @return a link to adobe connect user page
     */
    public static function block_display() {
        global $CFG, $USER;

        if (!helpmenow_adobeconnect_urlexists()) {
            return false;
        }

        $test = new moodle_url("$CFG->wwwroot/blocks/helpmenow/plugins/adobeconnect/meetnow.php");
        $test->param('username', $USER->username);
        return link_to_popup_window($test->out(), "adobeconnect", 'My Classroom', 800, 900, null, null, true);
    }

}

?>
